package enemies 
{
	import flash.geom.Point;
	import net.flashpunk.Entity;
	import net.flashpunk.*;
	import net.flashpunk.utils.*;
	import net.flashpunk.graphics.*;
	import player.Player;
	import worlds.rooms.Bedroom;
	import worlds.rooms.Livingroom;
	import player.Bubble;
	/**
	 * ...
	 * @author Commanderstitch
	 */
	public class KittenRed extends Entity 
	{		
		//define the dimensions of a single frame.
		public const SPRITE_WIDTH:Number = 23;
		public const SPRITE_HEIGHT:Number = 28;
		
		//create the spritemap
		
		public var playerSpritemap:Spritemap = new Spritemap(Assets.KITTENRED, SPRITE_WIDTH, SPRITE_HEIGHT);
		
		//helper variables
		public var curAnimation:String = "stand_down";
		public static var speed:Number = 1;
		public var flyhealth:Number = 3;
		private const turnspeed:Number = 100;
		private const SPEEDFORCOOKIE:Number = 200;
		private const RAD:Number = Math.PI / 180;
		private var vx:Number;
		private var vy:Number;
		private var angle:Number;
		private var targetDir_x:Number;
		private var targetDir_y:Number;
		private var target:Entity;
		private var image:Image;
		
		public function KittenRed(x:int,y:int) 
		{
			super(x, y);
			setupSpritesheet();
			graphic = playerSpritemap;
			playerSpritemap.play(curAnimation);
			setHitbox(10, 10,-5,-11);
			type = "fly";
			new Sfx(Assets.HISS).play();
			
			angle = 90;
		}
		public function begin():void
		{
			//Move kitten outside of walls
			while (collide("wall", x+40, y+40))
				{
					y++;
					x++;
				}
		}
		override public function update():void
		{
			var horizontalMovement:Boolean = true;
			var verticalMovement:Boolean = true;
			
			playerSpritemap.play(curAnimation);
			if ((Player.carryingcookie == false) && (Player.mastercookietrigger == false))
				getcookie();
			else if (world is Bedroom)
				checkBedroom();
			else if (world is Livingroom)
				checkLivingroom();
			
			var r:Bubble = collide("bubble", x, y) as Bubble;
			if (r)
			{
				r.destroy();
				flyhealth--;
			}
			if (flyhealth <= 0)
			{
				//play sucking sound
				destroy();
				new Sfx(Assets.DEADCAT).play();
				FP.world.add(new Captured(x, y));
			}
		}
		
		public function setupSpritesheet():void 
		{
			playerSpritemap.add("walk_down", [11, 10, 9, 8], 9, true);
			playerSpritemap.add("walk_up", [0,1,2,3], 9, true);
			playerSpritemap.add("walk_right", [0,1,2,3], 9, true);
			playerSpritemap.add("walk_left", [11,10,9,8], 9, true);
			playerSpritemap.add("stand_down", [0], 0, false);
			playerSpritemap.add("stand_up", [8], 0, false);
			playerSpritemap.add("stand_right", [0], 0, false);
			playerSpritemap.add("stand_left", [8], 0, false);
		}
		public function destroy():void
		{
			FP.world.remove(this);
		}
		public function checkBedroom():void
		{
			if (x > Bedroom.hero.x-10)
			{
				if (collide("wall", x - speed, y))
				{
					x -= 0;
				}
				else
				{
					curAnimation = "walk_right";
					x -= Math.random() * speed * 3;
				}
			}
			if (x < Bedroom.hero.x+10)
			{
				if (collide("wall", x + speed, y))
				{
					x += 0;
				}
				else
				{
					curAnimation = "walk_left";
					x += Math.random() * speed * 3;
				}
			}
			if (y > Bedroom.hero.y-10)
			{
				if (collide("wall", x, y-speed))
				{
					y -= 0;
				}
				else
				{
					y -= Math.random() * speed * 3;
				}
			}
			if (y < Bedroom.hero.y+10)
			{
				if (collide("wall", x, y+speed))
				{
					y += 0;
				}
				else
				{
					y += Math.random() * speed * 3;
				}
			}
			
			//check wheter no movement occured, in which case the idle animation for the last movement animation is played
			if ((x == Bedroom.hero.x+FP.clamp(2,1,5)) && (y == Bedroom.hero.y+FP.clamp(2,1,5)))
			{
				switch(curAnimation)
				{
					case "walk_left": curAnimation = "stand_left"; break;
					case "walk_right": curAnimation = "stand_right"; break;
					case "walk_up": curAnimation = "stand_up"; break;
					case "walk_down": curAnimation = "stand_down"; break;
				}
			}	
		}
		public function checkLivingroom():void
		{
			if (x > Livingroom.hero.x-10)
			{
				if (collide("wall", x - speed, y))
				{
					x -= 0;
				}
				else
				{
					curAnimation = "walk_right";
					x -= Math.random() * speed * 3;
				}
			}
			if (x < Livingroom.hero.x+10)
			{
				if (collide("wall", x + speed, y))
				{
					x += 0;
				}
				else
				{
					curAnimation = "walk_left";
					x += Math.random() * speed * 3;
				}
			}
			if (y > Livingroom.hero.y-10)
			{
				if (collide("wall", x, y-speed))
				{
					y -= 0;
				}
				else
				{
					y -= Math.random() * speed * 3;
				}
			}
			if (y < Livingroom.hero.y+10)
			{
				if (collide("wall", x, y+speed))
				{
					y += 0;
				}
				else
				{
					y += Math.random() * speed * 3;
				}
			}
			
			//check wheter no movement occured, in which case the idle animation for the last movement animation is played
			if ((x == Livingroom.hero.x+FP.clamp(2,1,5)) && (y == Livingroom.hero.y+FP.clamp(2,1,5)))
			{
				switch(curAnimation)
				{
					case "walk_left": curAnimation = "stand_left"; break;
					case "walk_right": curAnimation = "stand_right"; break;
					case "walk_up": curAnimation = "stand_up"; break;
					case "walk_down": curAnimation = "stand_down"; break;
				}
			}
		}
		public function getcookie():void
		{
			if (!target) getNewTarget();
			if (target) turnTowardsTarget();
			vx = SPEEDFORCOOKIE * Math.sin(angle * RAD) * FP.elapsed;
			vy = SPEEDFORCOOKIE * Math.cos(angle * RAD) * FP.elapsed;
			x += vx;
			y += vy;
			curAnimation = "walk_right";
		}
		public function turnTowardsTarget():void
		{
			targetDir_x = (target.x - x);
			targetDir_y = (target.y - y);
			if (vy * targetDir_x - vx * targetDir_y > 0)
				angle += turnspeed * FP.elapsed;
			else
				angle -= turnspeed * FP.elapsed;
		}
		public function getNewTarget():void
		{
			target = world.nearestToEntity("cookie", this);
		}
		
	}

}